# TVM 手册

[![PyPI][pypi-badge]][pypi-link]
[![GitHub issues][issue-badge]][issue-link]
[![GitHub forks][fork-badge]][fork-link]
[![GitHub stars][star-badge]][star-link]
[![GitHub license][license-badge]][license-link]
[![contributors][contributor-badge]][contributor-link]
[![watcher][watcher-badge]][watcher-link]
[![Binder][binder-badge]][binder-link]
[![Downloads][download-badge]][download-link]
[![PyPI - Downloads][install-badge]][install-link]
![repo size](https://img.shields.io/github/repo-size/xinetzone/tvm-book.svg)
[![Downloads Week](https://pepy.tech/badge/tvm-book/week)](https://pepy.tech/project/tvm-book)
[![Documentation Status][rtd-badge]][rtd-link]

[pypi-badge]: https://img.shields.io/pypi/v/tvm-book.svg
[pypi-link]: https://pypi.org/project/tvm-book/
[issue-badge]: https://img.shields.io/github/issues/xinetzone/tvm-book
[issue-link]: https://github.com/xinetzone/tvm-book/issues
[fork-badge]: https://img.shields.io/github/forks/xinetzone/tvm-book
[fork-link]: https://github.com/xinetzone/tvm-book/network
[star-badge]: https://img.shields.io/github/stars/xinetzone/tvm-book
[star-link]: https://github.com/xinetzone/tvm-book/stargazers
[license-badge]: https://img.shields.io/github/license/xinetzone/tvm-book
[license-link]: https://github.com/xinetzone/tvm-book/LICENSE
[contributor-badge]: https://img.shields.io/github/contributors/xinetzone/tvm-book
[contributor-link]: https://github.com/xinetzone/tvm-book/contributors
[watcher-badge]: https://img.shields.io/github/watchers/xinetzone/tvm-book
[watcher-link]: https://github.com/xinetzone/tvm-book/watchers
[binder-badge]: https://mybinder.org/badge_logo.svg
[binder-link]: https://mybinder.org/v2/gh/xinetzone/tvm-book/main
[install-badge]: https://img.shields.io/pypi/dw/tvm-book?label=pypi%20installs
[install-link]: https://pypistats.org/packages/tvm-book
[download-badge]: https://pepy.tech/badge/tvm-book
[download-link]: https://pepy.tech/project/tvm-book
[rtd-badge]: https://readthedocs.org/projects/tvm-book/badge/?version=latest
[rtd-link]: https://tvm-book.readthedocs.io/zh/latest/?badge=latest

打造优质的 TVM 中文社区。
